about summary refs log tree commit diff
path: root/elf/dl-load.c
diff options
context:
space:
mode:
Diffstat (limited to 'elf/dl-load.c')
-rw-r--r--elf/dl-load.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/elf/dl-load.c b/elf/dl-load.c
index 9d9ba94539..9856294c67 100644
--- a/elf/dl-load.c
+++ b/elf/dl-load.c
@@ -953,9 +953,9 @@ _dl_map_object_from_fd (const char *name, int fd, struct filebuf *fbp,
 	  /* If not loading the initial set of shared libraries,
 	     check whether we should permit loading a TLS segment.  */
 	  if (__builtin_expect (l->l_type == lt_library, 1)
-	      /* If GL(dl_tls_max_dtv_idx) == 0, then rtld.c did not
-		 set up TLS data structures, so don't use them now.  */
-	      || __builtin_expect (GL(dl_tls_max_dtv_idx), 1) != 0)
+	      /* If GL(dl_tls_dtv_slotinfo_list) == NULL, then rtld.c did
+		 not set up TLS data structures, so don't use them now.  */
+	      || __builtin_expect (GL(dl_tls_dtv_slotinfo_list) != NULL, 1))
 	    {
 	      /* Assign the next available module ID.  */
 	      l->l_tls_modid = _dl_next_tls_modid ();